#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Author:    thepoy
# @Email:     thepoy@163.com
# @File Name: __init__.py
# @Created:   2021-05-21 13:53:40
# @Modified:  2023-02-13 15:39:59

from colorful_logger.logger import (
    get_logger,
    logger,
    child_logger,
)
from colorful_logger.consts import DEBUG, INFO, WARNING, ERROR, FATAL
from colorful_logger.version import __version__

__all__ = [
    "logger",
    "get_logger",
    "child_logger",
    "DEBUG",
    "INFO",
    "WARNING",
    "ERROR",
    "FATAL",
    '__version__'
]



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Author:    thepoy
# @Email:     thepoy@163.com
# @File Name: types.py
# @Created:   2023-02-07 13:08:55
# @Modified:  2023-02-07 13:09:22

from os import PathLike

StrPath = str | PathLike[str]



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Author:    thepoy
# @Email:     thepoy@163.com
# @File Name: consts.py
# @Created:   2022-02-20 13:45:21
# @Modified:  2023-02-07 11:42:08

import logging
import os

from pathlib import Path

NOTSET = logging.NOTSET
DEBUG = logging.DEBUG
INFO = logging.INFO
WARNING = logging.WARNING
ERROR = logging.ERROR
FATAL = logging.FATAL
CRITICAL = logging.CRITICAL

TIME_FORMAT_WITH_DATE = "%Y-%m-%d %H:%M:%S"
TIME_FORMAT_WITHOUT_DATE = "%H:%M:%S.%f"

LOG_FORMAT = (
    "[%(levelname)s] %(asctime)s - %(name)s - %(pathname)s:%(lineno)d - %(message)s"
)

BASE_DIR = Path(os.path.dirname(__file__))
